# django-vises

![GitHub License](https://img.shields.io/github/license/rexzhang/django-vises)
[![PyPI - Version](https://img.shields.io/pypi/v/django-vises)](https://pypi.org/project/django-vises/)
![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https://raw.githubusercontent.com/rexzhang/django-vises/main/pyproject.toml)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-vises)](https://pypi.org/project/django-vises/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/django-vises)](https://pypi.org/project/django-vises/)

## Change log

### 1.0.3

- first public release
